%%
%% This is file `x2enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyoutenc.dtx  (with options: `X2')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs/
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% Copyright 1993-2019
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{x2enc.def}
  [2023/11/07 v1.0k Cyrillic encoding definition file]
\DeclareFontEncoding{X2}{}{}
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}
\DeclareTextAccent{\`}{\LastDeclaredEncoding}{0}
\DeclareTextAccent{\'}{\LastDeclaredEncoding}{1}
\DeclareTextAccent{\^}{\LastDeclaredEncoding}{2}
\DeclareTextAccent{\~}{\LastDeclaredEncoding}{3}
\DeclareTextAccent{\"}{\LastDeclaredEncoding}{4}
\DeclareTextAccent{\H}{\LastDeclaredEncoding}{5}
\DeclareTextAccent{\r}{\LastDeclaredEncoding}{6}
\DeclareTextAccent{\v}{\LastDeclaredEncoding}{7}
\DeclareTextAccent{\u}{\LastDeclaredEncoding}{8}
\DeclareTextAccent{\=}{\LastDeclaredEncoding}{9}
\DeclareTextAccent{\.}{\LastDeclaredEncoding}{10}
\DeclareTextAccent{\f}{\LastDeclaredEncoding}{18}
\DeclareTextAccent{\C}{\LastDeclaredEncoding}{19}
\DeclareTextAccent{\U}{\LastDeclaredEncoding}{20}
\DeclareTextCommand{\b}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\c}{\LastDeclaredEncoding}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-1ex}.\hidewidth}\egroup}
\DeclareTextCommand{\k}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup\oalign{\null#1\crcr\hidewidth\char12}\egroup}
\DeclareTextCommand{\textperthousand}{\LastDeclaredEncoding}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{\LastDeclaredEncoding}
   {\%\char 24\char 24 }
\DeclareTextSymbol{\textendash}{\LastDeclaredEncoding}{21}
\DeclareTextSymbol{\cyrdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textemdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textcompwordmark}{\LastDeclaredEncoding}{23}
\DeclareTextSymbol{\textvisiblespace}{\LastDeclaredEncoding}{32}
\DeclareTextSymbol{\textdollar}{\LastDeclaredEncoding}{36}
\DeclareTextSymbol{\textless}{\LastDeclaredEncoding}{60}
\DeclareTextSymbol{\textgreater}{\LastDeclaredEncoding}{62}
\DeclareTextSymbol{\textbackslash}{\LastDeclaredEncoding}{92}
\DeclareTextSymbol{\textasciicircum}{\LastDeclaredEncoding}{94}
\DeclareTextSymbol{\textunderscore}{\LastDeclaredEncoding}{95}
\DeclareTextSymbol{\textbraceleft}{\LastDeclaredEncoding}{123}
\DeclareTextSymbol{\textbar}{\LastDeclaredEncoding}{124}
\DeclareTextSymbol{\textbraceright}{\LastDeclaredEncoding}{125}
\DeclareTextSymbol{\textasciitilde}{\LastDeclaredEncoding}{126}
\DeclareTextSymbol{\textnumero}{\LastDeclaredEncoding}{157}
\DeclareTextSymbol{\textcurrency}{\LastDeclaredEncoding}{158}
\DeclareTextSymbol{\textsection}{\LastDeclaredEncoding}{159}
\DeclareTextSymbol{\textquotedbl}{\LastDeclaredEncoding}{34}
\DeclareTextSymbol{\textquoteleft}{\LastDeclaredEncoding}{96}
\DeclareTextSymbol{\textquoteright}{\LastDeclaredEncoding}{39}
\DeclareTextSymbol{\textquotedblleft}{\LastDeclaredEncoding}{16}
\DeclareTextSymbol{\textquotedblright}{\LastDeclaredEncoding}{17}
\DeclareTextSymbol{\quotedblbase}{\LastDeclaredEncoding}{189}
\DeclareTextSymbol{\CYRpalochka}{\LastDeclaredEncoding}{13}
\DeclareTextSymbol{\cyrlangle}{\LastDeclaredEncoding}{14}
\DeclareTextSymbol{\cyrrangle}{\LastDeclaredEncoding}{15}
\DeclareTextSymbol{\guillemotleft}{\LastDeclaredEncoding}{190}
\DeclareTextSymbol{\guillemetleft}{\LastDeclaredEncoding}{190}
\DeclareTextSymbol{\guillemotright}{\LastDeclaredEncoding}{191}
\DeclareTextSymbol{\guillemetright}{\LastDeclaredEncoding}{191}
\DeclareTextComposite{\.}{\LastDeclaredEncoding}{i}{`\i}
\DeclareTextSymbol{\CYRA}{\LastDeclaredEncoding}{192}
\DeclareTextSymbol{\cyra}{\LastDeclaredEncoding}{224}
\DeclareTextSymbol{\CYRB}{\LastDeclaredEncoding}{193}
\DeclareTextSymbol{\cyrb}{\LastDeclaredEncoding}{225}
\DeclareTextSymbol{\CYRV}{\LastDeclaredEncoding}{194}
\DeclareTextSymbol{\cyrv}{\LastDeclaredEncoding}{226}
\DeclareTextSymbol{\CYRG}{\LastDeclaredEncoding}{195}
\DeclareTextSymbol{\cyrg}{\LastDeclaredEncoding}{227}
\DeclareTextSymbol{\CYRD}{\LastDeclaredEncoding}{196}
\DeclareTextSymbol{\cyrd}{\LastDeclaredEncoding}{228}
\DeclareTextSymbol{\CYRE}{\LastDeclaredEncoding}{197}
\DeclareTextSymbol{\cyre}{\LastDeclaredEncoding}{229}
\DeclareTextSymbol{\CYRZH}{\LastDeclaredEncoding}{198}
\DeclareTextSymbol{\cyrzh}{\LastDeclaredEncoding}{230}
\DeclareTextSymbol{\CYRZ}{\LastDeclaredEncoding}{199}
\DeclareTextSymbol{\cyrz}{\LastDeclaredEncoding}{231}
\DeclareTextSymbol{\CYRI}{\LastDeclaredEncoding}{200}
\DeclareTextSymbol{\cyri}{\LastDeclaredEncoding}{232}
\DeclareTextSymbol{\CYRISHRT}{\LastDeclaredEncoding}{201}
\DeclareTextSymbol{\cyrishrt}{\LastDeclaredEncoding}{233}
\DeclareTextSymbol{\CYRK}{\LastDeclaredEncoding}{202}
\DeclareTextSymbol{\cyrk}{\LastDeclaredEncoding}{234}
\DeclareTextSymbol{\CYRL}{\LastDeclaredEncoding}{203}
\DeclareTextSymbol{\cyrl}{\LastDeclaredEncoding}{235}
\DeclareTextSymbol{\CYRM}{\LastDeclaredEncoding}{204}
\DeclareTextSymbol{\cyrm}{\LastDeclaredEncoding}{236}
\DeclareTextSymbol{\CYRN}{\LastDeclaredEncoding}{205}
\DeclareTextSymbol{\cyrn}{\LastDeclaredEncoding}{237}
\DeclareTextSymbol{\CYRO}{\LastDeclaredEncoding}{206}
\DeclareTextSymbol{\cyro}{\LastDeclaredEncoding}{238}
\DeclareTextSymbol{\CYRP}{\LastDeclaredEncoding}{207}
\DeclareTextSymbol{\cyrp}{\LastDeclaredEncoding}{239}
\DeclareTextSymbol{\CYRR}{\LastDeclaredEncoding}{208}
\DeclareTextSymbol{\cyrr}{\LastDeclaredEncoding}{240}
\DeclareTextSymbol{\CYRS}{\LastDeclaredEncoding}{209}
\DeclareTextSymbol{\cyrs}{\LastDeclaredEncoding}{241}
\DeclareTextSymbol{\CYRT}{\LastDeclaredEncoding}{210}
\DeclareTextSymbol{\cyrt}{\LastDeclaredEncoding}{242}
\DeclareTextSymbol{\CYRU}{\LastDeclaredEncoding}{211}
\DeclareTextSymbol{\cyru}{\LastDeclaredEncoding}{243}
\DeclareTextSymbol{\CYRF}{\LastDeclaredEncoding}{212}
\DeclareTextSymbol{\cyrf}{\LastDeclaredEncoding}{244}
\DeclareTextSymbol{\CYRH}{\LastDeclaredEncoding}{213}
\DeclareTextSymbol{\cyrh}{\LastDeclaredEncoding}{245}
\DeclareTextSymbol{\CYRC}{\LastDeclaredEncoding}{214}
\DeclareTextSymbol{\cyrc}{\LastDeclaredEncoding}{246}
\DeclareTextSymbol{\CYRCH}{\LastDeclaredEncoding}{215}
\DeclareTextSymbol{\cyrch}{\LastDeclaredEncoding}{247}
\DeclareTextSymbol{\CYRSH}{\LastDeclaredEncoding}{216}
\DeclareTextSymbol{\cyrsh}{\LastDeclaredEncoding}{248}
\DeclareTextSymbol{\CYRSHCH}{\LastDeclaredEncoding}{217}
\DeclareTextSymbol{\cyrshch}{\LastDeclaredEncoding}{249}
\DeclareTextSymbol{\CYRHRDSN}{\LastDeclaredEncoding}{218}
\DeclareTextSymbol{\cyrhrdsn}{\LastDeclaredEncoding}{250}
\DeclareTextSymbol{\CYRERY}{\LastDeclaredEncoding}{219}
\DeclareTextSymbol{\cyrery}{\LastDeclaredEncoding}{251}
\DeclareTextSymbol{\CYRSFTSN}{\LastDeclaredEncoding}{220}
\DeclareTextSymbol{\cyrsftsn}{\LastDeclaredEncoding}{252}
\DeclareTextSymbol{\CYREREV}{\LastDeclaredEncoding}{221}
\DeclareTextSymbol{\cyrerev}{\LastDeclaredEncoding}{253}
\DeclareTextSymbol{\CYRYU}{\LastDeclaredEncoding}{222}
\DeclareTextSymbol{\cyryu}{\LastDeclaredEncoding}{254}
\DeclareTextSymbol{\CYRYA}{\LastDeclaredEncoding}{223}
\DeclareTextSymbol{\cyrya}{\LastDeclaredEncoding}{255}
\DeclareTextSymbol{\CYRGUP}{X2}{128}
\DeclareTextSymbol{\cyrgup}{X2}{160}
\DeclareTextSymbol{\CYRGHCRS}{X2}{129}
\DeclareTextSymbol{\cyrghcrs}{X2}{161}
\DeclareTextSymbol{\CYRGDSC}{X2}{130}
\DeclareTextSymbol{\cyrgdsc}{X2}{162}
\DeclareTextSymbol{\CYRGHK}{X2}{131}
\DeclareTextSymbol{\cyrghk}{X2}{163}
\DeclareTextSymbol{\CYRSHHA}{X2}{132}
\DeclareTextSymbol{\cyrshha}{X2}{164}
\DeclareTextSymbol{\CYRZHDSC}{X2}{133}
\DeclareTextSymbol{\cyrzhdsc}{X2}{165}
\DeclareTextSymbol{\CYRZDSC}{X2}{134}
\DeclareTextSymbol{\cyrzdsc}{X2}{166}
\DeclareTextSymbol{\CYRABHDZE}{X2}{135}
\DeclareTextSymbol{\cyrabhdze}{X2}{167}
\DeclareTextSymbol{\CYRYI}{X2}{136}
\DeclareTextSymbol{\cyryi}{X2}{168}
\DeclareTextSymbol{\CYRKDSC}{X2}{137}
\DeclareTextSymbol{\cyrkdsc}{X2}{169}
\DeclareTextSymbol{\CYRKBEAK}{X2}{138}
\DeclareTextSymbol{\cyrkbeak}{X2}{170}
\DeclareTextSymbol{\CYRKHK}{X2}{139}
\DeclareTextSymbol{\cyrkhk}{X2}{171}
\DeclareTextSymbol{\CYRLHK}{X2}{140}
\DeclareTextSymbol{\cyrlhk}{X2}{172}
\DeclareTextSymbol{\CYRNDSC}{X2}{141}
\DeclareTextSymbol{\cyrndsc}{X2}{173}
\DeclareTextSymbol{\CYRNG}{X2}{142}
\DeclareTextSymbol{\cyrng}{X2}{174}
\DeclareTextSymbol{\CYRNHK}{X2}{143}
\DeclareTextSymbol{\cyrnhk}{X2}{175}
\DeclareTextSymbol{\CYROTLD}{X2}{144}
\DeclareTextSymbol{\cyrotld}{X2}{176}
\DeclareTextSymbol{\CYRSDSC}{X2}{145}
\DeclareTextSymbol{\cyrsdsc}{X2}{177}
\DeclareTextSymbol{\CYRUSHRT}{X2}{146}
\DeclareTextSymbol{\cyrushrt}{X2}{178}
\DeclareTextSymbol{\CYRY}{X2}{147}
\DeclareTextSymbol{\cyry}{X2}{179}
\DeclareTextSymbol{\CYRYHCRS}{X2}{148}
\DeclareTextSymbol{\cyryhcrs}{X2}{180}
\DeclareTextSymbol{\CYRHDSC}{X2}{149}
\DeclareTextSymbol{\cyrhdsc}{X2}{181}
\DeclareTextSymbol{\CYRHHK}{X2}{150}
\DeclareTextSymbol{\cyrhhk}{X2}{182}
\DeclareTextSymbol{\CYRCHLDSC}{X2}{151}
\DeclareTextSymbol{\cyrchldsc}{X2}{183}
\DeclareTextSymbol{\CYRCHRDSC}{X2}{152}
\DeclareTextSymbol{\cyrchrdsc}{X2}{184}
\DeclareTextSymbol{\CYRIE}{X2}{153}
\DeclareTextSymbol{\cyrie}{X2}{185}
\DeclareTextSymbol{\CYRSCHWA}{X2}{154}
\DeclareTextSymbol{\cyrschwa}{X2}{186}
\DeclareTextSymbol{\CYREPS}{X2}{155}
\DeclareTextSymbol{\cyreps}{X2}{187}
\DeclareTextSymbol{\CYRYO}{\LastDeclaredEncoding}{156}
\DeclareTextSymbol{\cyryo}{\LastDeclaredEncoding}{188}
\DeclareTextSymbol{\CYRAE}{X2}{65}
\DeclareTextSymbol{\cyrae}{X2}{97}
\DeclareTextSymbol{\CYRDJE}{X2}{66}
\DeclareTextSymbol{\cyrdje}{X2}{98}
\DeclareTextSymbol{\CYRTSHE}{X2}{67}
\DeclareTextSymbol{\cyrtshe}{X2}{99}
\DeclareTextSymbol{\CYRABHCH}{X2}{68}
\DeclareTextSymbol{\cyrabhch}{X2}{100}
\DeclareTextSymbol{\CYRABHCHDSC}{X2}{69}
\DeclareTextSymbol{\cyrabhchdsc}{X2}{101}
\DeclareTextSymbol{\CYRKVCRS}{X2}{70}
\DeclareTextSymbol{\cyrkvcrs}{X2}{102}
\DeclareTextSymbol{\CYRKHCRS}{X2}{71}
\DeclareTextSymbol{\cyrkhcrs}{X2}{103}
\DeclareTextSymbol{\CYRLDSC}{X2}{72}
\DeclareTextSymbol{\cyrldsc}{X2}{104}
\DeclareTextSymbol{\CYRII}{\LastDeclaredEncoding}{73}
\DeclareTextSymbol{\cyrii}{\LastDeclaredEncoding}{105}
\DeclareTextSymbol{\CYRJE}{\LastDeclaredEncoding}{74}
\DeclareTextSymbol{\cyrje}{\LastDeclaredEncoding}{106}
\DeclareTextSymbol{\CYRLJE}{X2}{75}
\DeclareTextSymbol{\cyrlje}{X2}{107}
\DeclareTextSymbol{\CYRMDSC}{X2}{76}
\DeclareTextSymbol{\cyrmdsc}{X2}{108}
\DeclareTextSymbol{\CYRNJE}{X2}{77}
\DeclareTextSymbol{\cyrnje}{X2}{109}
\DeclareTextSymbol{\CYRABHHA}{X2}{78}
\DeclareTextSymbol{\cyrabhha}{X2}{110}
\DeclareTextSymbol{\CYRPHK}{X2}{79}
\DeclareTextSymbol{\cyrphk}{X2}{111}
\DeclareTextSymbol{\CYRRDSC}{X2}{80}
\DeclareTextSymbol{\cyrrdsc}{X2}{112}
\DeclareTextSymbol{\CYRQ}{\LastDeclaredEncoding}{81}
\DeclareTextSymbol{\cyrq}{\LastDeclaredEncoding}{113}
\DeclareTextSymbol{\CYRTDSC}{X2}{82}
\DeclareTextSymbol{\cyrtdsc}{X2}{114}
\DeclareTextSymbol{\CYRDZE}{\LastDeclaredEncoding}{83}
\DeclareTextSymbol{\cyrdze}{\LastDeclaredEncoding}{115}
\DeclareTextSymbol{\CYRTETSE}{X2}{84}
\DeclareTextSymbol{\cyrtetse}{X2}{116}
\DeclareTextSymbol{\CYRDZHE}{X2}{85}
\DeclareTextSymbol{\cyrdzhe}{X2}{117}
\DeclareTextSymbol{\CYRCHVCRS}{X2}{86}
\DeclareTextSymbol{\cyrchvcrs}{X2}{118}
\DeclareTextSymbol{\CYRW}{\LastDeclaredEncoding}{87}
\DeclareTextSymbol{\cyrw}{\LastDeclaredEncoding}{119}
\DeclareTextSymbol{\CYRYAT}{X2}{88}
\DeclareTextSymbol{\cyryat}{X2}{120}
\DeclareTextSymbol{\CYRBYUS}{X2}{89}
\DeclareTextSymbol{\cyrbyus}{X2}{121}
\DeclareTextSymbol{\CYRIZH}{X2}{90}
\DeclareTextSymbol{\cyrizh}{X2}{122}
\DeclareTextSymbol{\CYRDELTA}{X2}{28}
\DeclareTextSymbol{\cyrdelta}{X2}{29}
\DeclareTextSymbol{\CYRNLHK}{X2}{30}
\DeclareTextSymbol{\cyrnlhk}{X2}{31}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRE}{156}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyre}{188}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRI}{201}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyri}{233}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRII}{136}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyrii}{168}
\DeclareTextComposite{\c}{\LastDeclaredEncoding}{\CYRZ}{134}
\DeclareTextComposite{\c}{\LastDeclaredEncoding}{\cyrz}{166}
\DeclareTextComposite{\k}{\LastDeclaredEncoding}{\CYRS}{145}
\DeclareTextComposite{\k}{\LastDeclaredEncoding}{\cyrs}{177}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRU}{146}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyru}{178}
\DeclareTextComposite{\k}{X2}{\CYRABHCH}{69}
\DeclareTextComposite{\k}{X2}{\cyrabhch}{101}
\endinput
%%
%% End of file `x2enc.def'.
